# Corpus of Place Representations (COPR) / COPR.py

COPR /ˈkɒp.ər/ is the Corpus of Place Representations, a collection of semantically annotated place representations that are made available for research. It is run by the Space &amp; Place LAB, currently located at the University of Salzburg.

The COPR.py as part of the COPR API is an easy-to-use library to access data from the [Corpus of Place Representations (COPR)](https://copr.space-and-place.net).

Website: [https://copr.space-and-place.net](https://copr.space-and-place.net)

## Installation

To install the library, you will need [Python3](https://www.python.org) and [pip](https://pip.pypa.io).  Then, run
```bash
pip3 install copr.py
```
## Publishing
You can publish the library by executing the following steps:
```bash
cd copr.py
yarn install:publish
yarn publish
```

## Usage

For further information, see [https://copr.space-and-place.net](https://copr.space-and-place.net).

## Authorship and License

This application is written and maintained by Franz-Benjamin Mocnik, <mail@space-and-place.net>.

The code is licensed under the [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/).
